*[array-like object]: e.g. Python list, NumPy and JAX array or QuTiP Qobj
*[Array-like object]: e.g. Python list, NumPy and JAX array or QuTiP Qobj
*[array-like objects]: e.g. Python lists, NumPy and JAX arrays or QuTiP Qobjs
*[Array-like objects]: e.g. Python lists, NumPy and JAX arrays or QuTiP Qobjs
*[PWC]: piecewise constant
*[SME]: stochastic master equation
